package com.javahonk;

import java.io.File;
import java.io.FileOutputStream;
import java.time.LocalDate;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

import org.apache.logging.log4j.LogManager;
import org.apache.logging.log4j.Logger;
import org.apache.poi.xssf.usermodel.XSSFSheet;
import org.apache.poi.xssf.usermodel.XSSFWorkbook;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.factory.annotation.Value;


public class JavaHonkReport extends JavaHonkExcelReportGenerator{
	
	private static final Logger logger = LogManager.getLogger(JavaHonkReport.class);

	File attachment = null; 
	
	@Autowired
	public MailHelper mailHelper;
	
	@Value("${javahonk.report.template}")
	private String template;
	
	@Value("#{'${javahonk_report_to_address}'.split(',')}") 
	private List<String> javahonk_report_to_address;
	
	@Value("${javahonk_report_from_address}")
	private String javahonk_report_from_address;
	
	@SuppressWarnings({ "unchecked", "rawtypes" })
	public void generateReport() {

		logger.info("JavaHonk report...");

		attachment = createDSPSGalaxySheet("JavaHonk Report");
		
		String localDate = LocalDate.now().toString();			
		String subject = "JavaHonk Sample Report_" + localDate; 
		String reportName = "JavaHonkReport" + localDate+".xlsx";
		
		attachment = createDSPSGalaxySheet(reportName);
		Map<String,File> attachments = new HashMap<>();
		attachments.put(reportName, attachment);
		
		Map map = new HashMap();			
		map.put("date", LocalDate.now());
		map.put("noOfRecords", new Integer(10));
    	
		mailHelper.sendTemplatedMimeMessage(map, template, javahonk_report_from_address, javahonk_report_to_address, subject, attachments);

		logger.info("Java Honk report sent successfully...");

	}
    
    public File createDSPSGalaxySheet(String reportName) {
		
		File file = null;
		
		try {
			
			XSSFWorkbook workbook = new XSSFWorkbook();
			XSSFSheet javahonkSheet1 = workbook.createSheet("JAVAHONK_DATA1");
			XSSFSheet javahonkSheet2 = workbook.createSheet("JAVAHONK_DATA2");
			XSSFSheet javahonkSheet3 = workbook.createSheet("JAVAHONK_DATA3");

			setUpWorkSheets(workbook,javahonkSheet1, JavaHonkReportFields.getJavaHonkReportFields());
			setUpWorkSheets(workbook,javahonkSheet2, JavaHonkReportFields.getJavaHonkReportFields());
			setUpWorkSheets(workbook,javahonkSheet3, JavaHonkReportFields.getJavaHonkReportFields());			
			
			List<JavaHonkReportModel> javaHonkData1 = new ArrayList<JavaHonkReportModel>();
			
			for (int i = 0; i < 10; i++) {
				
				JavaHonkReportModel javaHonkReportModel = new JavaHonkReportModel();
				javaHonkReportModel.setFirstName("firstName");
				javaHonkReportModel.setLastName("lastName");
				javaHonkReportModel.setCity("city");
				javaHonkReportModel.setPhone("phone");
				javaHonkReportModel.setState("state");
				javaHonkReportModel.setZip("zip");
				javaHonkData1.add(javaHonkReportModel);
			}
			
			processDSPSGalaxyWorkSheet(javahonkSheet1, javaHonkData1);
			processDSPSGalaxyWorkSheet(javahonkSheet2, javaHonkData1);
			processDSPSGalaxyWorkSheet(javahonkSheet3, javaHonkData1);
						
			FileOutputStream out = new FileOutputStream(reportName+".xlsx");
			workbook.write(out);
			out.close();
			file = new  File(reportName+".xlsx");
			
		} 
		catch (Exception e) {
			
			logger.error("Error generating excel report:\n", e);
		}
	
		return file;
	}    
    
}
